@@ -95,6 +95,7 @@ sub new {
 #   Purpose: Find a certain file
 #
 #   Inputs:  $self - Instance
+#            $options - Options hash ref
 #            $gooddirs - List of directories where to search; these
 #                directories are accepted immediately if a file is
 #                found there
@@ -113,8 +114,8 @@ sub new {
 #
 ############################################################################
 
-sub Search ($$$$$) {
-    my($self, $gooddirs, $dirs, $files, $prompt) = @_;
+sub Search ($$$$$$) {
+    my($self, $options, $gooddirs, $dirs, $files, $prompt) = @_;
 
     my ($dir, $file, $realfile);
     foreach $dir (@$gooddirs) {
@@ -141,8 +142,10 @@ sub Search ($$$$$) {
     }
     $gooddir ||= $$gooddirs[0] || $$dirs[0];
 
-    $gooddir = ExtUtils::MakeMaker::prompt($prompt, $gooddir)
-	||  $gooddir;  # for 5.002;
+    if ($options->{'prompt'}) {
+	$gooddir = ExtUtils::MakeMaker::prompt($prompt, $gooddir)
+	    ||  $gooddir;  # for 5.002;
+    }
 
     foreach $file (@$files) {
 	if (-f ($realfile = "$gooddir/$file")) {
@@ -160,15 +163,15 @@ sub Search ($$$$$) {
 }
 
 
-sub SearchHeaders ($$$$) {
-    my($self, $gooddirs, $dirs, $files) = @_;
+sub SearchHeaders ($$$$$) {
+    my($self, $options, $gooddirs, $dirs, $files) = @_;
     my @d = @$dirs;
     if ($self->{'headerdir'}) {
 	unshift(@d, $self->{'headerdir'});
     }
 
     my($headerdir, $gooddir) = $self->Search
-	($gooddirs, \@d, $files,
+	($options, $gooddirs, \@d, $files,
 	 "Where is your " . $self->{'description'}
 	 . " installed? Please tell me the directory that\n"
 	 . "contains the subdir 'include'.");
@@ -177,15 +180,15 @@ sub SearchHeaders ($$$$) {
     ($headerdir, $gooddir);
 }
 
-sub SearchLibs ($$$$) {
-    my($self, $gooddirs, $dirs, $files) = @_;
+sub SearchLibs ($$$$$) {
+    my($self, $options, $gooddirs, $dirs, $files) = @_;
     my @d = @$dirs;
     if ($self->{'libdir'}) {
 	unshift(@d, $self->{'libdir'});
     }
 
     my($libdir, $gooddir, $realfile) = $self->Search
-	($gooddirs, \@d, $files,
+	($options, $gooddirs, \@d, $files,
 	 "Where is your " . $self->{'description'}
 	 . " installed? Please tell me the directory that\n"
 	 . "contains the subdir 'lib'.");
@@ -219,10 +222,8 @@ sub CheckForLibGcc {
     # We try to fix this by always linking against libgcc.a. Unfortunately
     # it's somewhat hard to find out the path of this file ...
     #
-    if ($Config::Config{'osname'} eq '(free|net)bsd') {
-	# Under NetBSD and FreeBSD libc is nothing else than libgcc
-	return '';
-    }
+    # Under NetBSD, FreeBSD and OpenBSD libc is nothing else than libgcc
+    return '' if ($Config::Config{'osname'} =~ /^(free|net|open)bsd$/);
     if ($Config::Config{'gccversion'} eq '') {
 	# This isn't gcc. Question is, does libmysqlclient.a require gcc?
 	require Symbol;
@@ -253,7 +254,7 @@ MSG
 	return '';
     }
 
-    my($libgccfile) = `$Config::Config{'cc'} -print-libgcc-file-name 2>&1`;
+    my $libgccfile = `$Config::Config{'cc'} -print-libgcc-file-name 2>&1`;
     my($libgccdir);
     if ($libgccfile =~ /^\S+$/) {
 	if ($libgccfile =~ /(.*)\/lib(\S+)\.a/) {
@@ -299,8 +300,8 @@ MSG
 }
 
 
-sub Initialize ($) {
-    my($self) = @_;
+sub Initialize ($$) {
+    my($self, $options) = @_;
 
     my @mysqldirs = ($^O =~ /mswin32/i) ? qw(C:/mysql C:/my/myodbc) :
 	qw{/usr/local /usr/local/mysql /usr /usr/mysql /opt/mysql};
@@ -313,16 +314,16 @@ sub Initialize ($) {
     }
 
     my $headerdir;
-    if (exists($ENV{'MYSQL_HEADERDIR'})) {
-	$headerdir = $ENV{'MYSQL_HEADERDIR'};
+    if (exists($options->{'mysql-incdir'})) {
+	$headerdir = $options->{'mysql-incdir'};
     } else {
 	($headerdir, $gooddir) = $self->SearchHeaders
-	    (\@gooddirs, \@mysqldirs,
+	    ($options, \@gooddirs, \@mysqldirs,
 	     ["include/mysql/mysql.h", "include/mysql.h"]);
     }
     my($libdir, $gooddir, $libfile);
-    if (exists($ENV{'MYSQL_LIBDIR'})) {
-	$libdir = $ENV{'MYSQL_LIBDIR'};
+    if (exists($options->{'mysql-libdir'})) {
+	$libdir = $options->{'mysql-libdir'};
     } else {
 	my(@searchpath, $file, $dir);
 	if ($^O =~ /mswin32/i) {
@@ -340,13 +341,14 @@ sub Initialize ($) {
 	    }
 	}
 	($libdir, $gooddir, $libfile)
-	    = $self->SearchLibs(\@gooddirs, \@mysqldirs, \@searchpath);
+	    = $self->SearchLibs($options, \@gooddirs, \@mysqldirs,
+				\@searchpath);
     }
 
     my $sysliblist;
     $self->{'static_libs'} = '';
     $self->{'final_libs'} = '';
-    if ($::options->{'static'}) {
+    if ($options->{'static'}) {
 	if ($libfile !~ /\.a/  &&  $libfile !~ /\.lib/) {
 	    die "Cannot use option -static with shared library file $libfile";
 	}
